<?php

declare(strict_types=1);
/**
 * This file is part of Hyperf.
 *
 * @link     https://www.hyperf.io
 * @document https://hyperf.wiki
 * @contact  group@hyperf.io
 * @license  https://github.com/hyperf/hyperf/blob/master/LICENSE
 */

namespace App\Controller;

use App\Extended\Response\Response;
use App\Infrastructure\DDD\HeaderInfo\HeaderInfo;
use Hyperf\Context\Context;
use Hyperf\Di\Annotation\Inject;
use Hyperf\HttpServer\Contract\RequestInterface;
use Hyperf\HttpServer\Contract\ResponseInterface;
use Hyperf\Validation\Contract\ValidatorFactoryInterface;
use Psr\Container\ContainerInterface;
use SuperRhino\Utils\Auth\Auth;

abstract class AbstractController {
    #[Inject]
    protected ContainerInterface $container;

    #[Inject]
    protected RequestInterface $request;

    #[Inject]
    protected ResponseInterface $response;

    #[Inject]
    protected ValidatorFactoryInterface $validationFactory;


    protected function getRequestAuth(): ?Auth {
        return Context::get(Auth::AUTH_KEY);
    }

    protected function getHeaderInfo() {
        return Context::get(HeaderInfo::HEADER_KEY);
    }

    protected function getCurrentUserId(): ?string {
        return $this->getRequestAuth()?->getUserId();
    }

    protected function validate(array $rule): void {
        $validator = $this->validationFactory->make($this->request->all(), $rule);
        $validator->validate();
    }

    protected function response($data = null, int $code = 0, string $message = '') {
        return Response::make($data, $code, $message)->response();
    }
}
