<?php

declare(strict_types=1);
/**
 * This file is part of Hyperf.
 *
 * @link     https://www.hyperf.io
 * @document https://hyperf.wiki
 * @contact  group@hyperf.io
 * @license  https://github.com/hyperf/hyperf/blob/master/LICENSE
 */

namespace App\Exception\Handler;

use App\Constants\ErrorCode;
use App\Exception\BusinessException;
use App\Extended\Response\Response;

use Hyperf\ExceptionHandler\ExceptionHandler;
use Hyperf\HttpServer\Contract\RequestInterface;
use Hyperf\Context\ApplicationContext;
use Psr\Http\Message\ResponseInterface;
use SuperRhino\Utils\Auth\Exception\AuthException;
use SuperRhino\Utils\Logger\Log;
use Throwable;


class AppExceptionHandler extends ExceptionHandler {

    public function handle(Throwable $throwable, ResponseInterface $response) {
        if ($throwable instanceof BusinessException) {
            // 阻止异常冒泡
            $this->stopPropagation();
            return Response::make(null, $throwable->getCode(), $throwable->getMessage())->response();
        } elseif ($throwable instanceof AuthException) {
            // 阻止异常冒泡
            $this->stopPropagation();
            return Response::make(null, ErrorCode::AUTH_ERROR, ErrorCode::getMessage(ErrorCode::AUTH_ERROR))->response();
        } else {
            $container = ApplicationContext::getContainer();
            $req = $container->get(RequestInterface::class);
            $reqData = $req->all();
            //密码会打到日志里。
            unset($reqData['password']);
            Log::error('ServiceError', [$throwable->getMessage(), $throwable->getLine(), $throwable->getFile(), $throwable->getTraceAsString(), 'path' => $req->url(), 'param' => $reqData, 'method' => $req->getMethod()]);
            if (!DEV) {
                // 阻止异常冒泡
                $this->stopPropagation();
                return Response::make(null, 500, "Server Error")->response();
            }
        }
        return $response;
    }

    public function isValid(Throwable $throwable): bool {
        return true;
    }
}
