<?php

declare(strict_types=1);
/**
 * This file is part of Hyperf.
 *
 * @link     https://www.hyperf.io
 * @document https://hyperf.wiki
 * @contact  group@hyperf.io
 * @license  https://github.com/hyperf/hyperf/blob/master/LICENSE
 */

namespace App\Exception\Handler;

use Hyperf\Validation\ValidationException;
use Hyperf\Validation\ValidationExceptionHandler;
use Hyperf\HttpMessage\Stream\SwooleStream;
use Psr\Http\Message\ResponseInterface;
use Throwable;


class CusValidationExceptionHandler extends ValidationExceptionHandler {

    public function handle(Throwable $throwable, ResponseInterface $response) {
        $this->stopPropagation();
        /** @var ValidationException $throwable */
        $body = $throwable->validator->errors()->first();
        if (!$response->hasHeader('content-type')) {
            $response = $response->withAddedHeader('content-type', 'text/json; charset=utf-8');
        }
        $data = json_encode([
            'code' => 700,
            'message' => $body,
        ], JSON_UNESCAPED_UNICODE);
        return $response->withStatus($throwable->status)->withBody(new SwooleStream($data));
    }
}