<?php

namespace App\Extended\GuzzleClient;

use SuperRhino\Utils\GuzzleClient\ClientFactoryInterface;
use Hyperf\Guzzle\CoroutineHandler;
use GuzzleHttp\Client;
use GuzzleHttp\HandlerStack;
use Hyperf\Utils\Coroutine;
use Psr\Container\ContainerInterface;

class ClientFactory implements ClientFactoryInterface {
    /**
     * @var ContainerInterface
     */
    private $container;

    public function __construct(ContainerInterface $container) {
        $this->container = $container;
    }

    public function create(array $options = []): Client {
        $stack = null;
        if (Coroutine::inCoroutine()) {
            $stack = HandlerStack::create(new CoroutineHandler());
        }

        $config = array_replace(['handler' => $stack], $options);

        if (method_exists($this->container, 'make')) {
            // Create by DI for AOP.
            return $this->container->make(Client::class, ['config' => $config]);
        }
        return new Client($config);
    }
}