<?php

declare(strict_types=1);
/**
 * This file is part of Hyperf.
 *
 * @link     https://www.hyperf.io
 * @document https://hyperf.wiki
 * @contact  group@hyperf.io
 * @license  https://github.com/hyperf/hyperf/blob/master/LICENSE
 */

namespace App\Extended\GuzzleClient;

use GuzzleHttp\Client;
use Hyperf\Guzzle\HandlerStackFactory;
use Psr\Container\ContainerInterface;
use SuperRhino\Utils\GuzzleClient\ClientFactoryInterface;

class PoolClientFactory implements ClientFactoryInterface {
    /**
     * @var ContainerInterface
     */
    private $container;

    public function __construct(ContainerInterface $container) {
        $this->container = $container;
    }

    public function create(array $options = []): Client {

        $factory = new HandlerStackFactory();
        $option = config('guzzle_client', []);
        $stack = $factory->create($option);

        $config = array_replace(['handler' => $stack], $options);

        if (method_exists($this->container, 'make')) {
            // Create by DI for AOP.
            return $this->container->make(Client::class, ['config' => $config]);
        }
        return new Client($config);
    }
}
