<?php

namespace App\Infrastructure\DDD\HeaderInfo;

use App\Constants\ErrorCode;
use App\Exception\BusinessException;
use Hyperf\Context\Context;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\RequestHandlerInterface;
use SuperRhino\Utils\Common\BaseMiddleware;


/**
 * Class DeviceMiddleware
 * @package App\Middleware
 * 设备信息中间件，判断请求头中是否包含必要的信息，同时放到上下文中
 */
class DeviceMiddleware extends BaseMiddleware {

    /**
     * @var string[] 忽略的路径
     */
    protected array $ignorePath = [

    ];

    /**
     * @var string[] 登录接口必须有设备信息
     */
    protected array $required = [

    ];

    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler): ResponseInterface {
        $type = $request->getHeaderLine('osType');
        $version = $request->getHeaderLine('appVersion');
        $channel = $request->getHeaderLine('channel');

        $path = $request->getUri()->getPath();

        if (!$this->ignore($path)) {
            if (empty($type) || empty($version) || empty($channel)) {
                //登录注册接口必须要有
                if ($this->required($path)) {
                    throw new BusinessException(ErrorCode::SERVER_ERROR, 'request info error');
                }
            } else {
                $header = new HeaderInfo($type, $channel, $version);
                Context::set(HeaderInfo::HEADER_KEY, $header);
            }
        }

        return $handler->handle($request);
    }
}