<?php

declare(strict_types=1);
/**
 * This file is part of Hyperf.
 *
 * @link     https://www.hyperf.io
 * @document https://hyperf.wiki
 * @contact  group@hyperf.io
 * @license  https://github.com/hyperf/hyperf/blob/master/LICENSE
 */

$appEnv = \Hyperf\Support\env('APP_ENV', 'dev');

$patch = \Hyperf\Support\env('LOG_PATH') ?? BASE_PATH . '/runtime/logs/';
$defaultFile = $patch . 'app.log';
$sqlFile = $patch . 'sql.log';
$adminFile = $patch . 'admin.log';
$queueFile = $patch . 'queue.log';

$systemLevel = Monolog\Logger::NOTICE;
$systemStdoutLevel = Monolog\Logger::INFO;
if (PRODUCTION) {
    //生产环境
    $level = Monolog\Logger::NOTICE;
} elseif (PREVIEW) {
    //预发布环境
    $level = Monolog\Logger::INFO;
    if (\Hyperf\Support\env('SYSTEM_DEBUG_LOG')) {
        $systemLevel = Monolog\Logger::DEBUG;
        $systemStdoutLevel = Monolog\Logger::DEBUG;
    }
} else {
    //测试环境
    $level = Monolog\Logger::DEBUG;
    if (\Hyperf\Support\env('SYSTEM_DEBUG_LOG')) {
        $systemLevel = Monolog\Logger::DEBUG;
        $systemStdoutLevel = Monolog\Logger::DEBUG;
    }
}

/*$hyperfRotatingFileHandler = [
    'class' => Monolog\Handler\RotatingFileHandler::class,
    'constructor' => [
        'filename' => $defaultFile,
        'maxFiles' => 7,
        'level' => $level,
        'bubble' => true,
        'filePermission' => 0777
    ],
];*/

$defaultRotatingFileHandler = [
    'class' => Monolog\Handler\RotatingFileHandler::class,
    'constructor' => [
        'filename' => $defaultFile,
        'maxFiles' => 3,
        'level' => $level,
        'bubble' => true,
        'filePermission' => 0777
    ],
];
$sqlRotatingFileHandler = [
    'class' => Monolog\Handler\RotatingFileHandler::class,
    'constructor' => [
        'filename' => $sqlFile,
        'maxFiles' => 3,
        'level' => $level,
        'bubble' => true,
        'filePermission' => 0777
    ],
];
$adminRotatingFileHandler = [
    'class' => Monolog\Handler\RotatingFileHandler::class,
    'constructor' => [
        'filename' => $adminFile,
        'maxFiles' => 3,
        'level' => Monolog\Logger::INFO,
        'bubble' => false,
        'filePermission' => 0777
    ],
];
$queueRotatingFileHandler = [
    'class' => Monolog\Handler\RotatingFileHandler::class,
    'constructor' => [
        'filename' => $queueFile,
        'maxFiles' => 3,
        'level' => Monolog\Logger::INFO,
        'bubble' => false,
        'filePermission' => 0777
    ],
];
$systemRotatingFileHandler = [
    'class' => Monolog\Handler\RotatingFileHandler::class,
    'constructor' => [
        'filename' => $defaultFile,
        'maxFiles' => 3,
        'level' => $systemLevel,
        'bubble' => true,
        'filePermission' => 0777
    ],
];

$systemStdoutStreamHandler = [
    'class' => Monolog\Handler\StreamHandler::class,
    'constructor' => [
        'stream' => 'php://stdout',//BASE_PATH . '/runtime/logs/hyperf.log',
        'level' => $systemStdoutLevel,
    ]
];

$jsonFormatter = [
    'class' => \App\Extended\Logger\JsonFormatter::class,
    'constructor' => [],
];

$lineFormatter = [
    'class' => Monolog\Formatter\LineFormatter::class,
    'constructor' => [
        'format' => "[%datetime%] %channel%.%level_name%: %message% %context% %extra% user:%user_id% session:%session_id%\n",
        'dateFormat' => 'Y-m-d H:i:s',
        'allowInlineLineBreaks' => true,
    ]
];

$systemLineFormatter = [
    'class' => Monolog\Formatter\LineFormatter::class,
    'constructor' => [
        'format' => "[%datetime%] %channel%.%level_name%: %message%\n",
        'dateFormat' => 'Y-m-d H:i:s',
        'allowInlineLineBreaks' => true,
    ]
];

$processors = [
    [
        'class' => Monolog\Processor\IntrospectionProcessor::class,
        'constructor' => [
            'level' => $level,
            'skipClassesPartials' => ['SuperRhino\\Utils\\Logger\\Log', 'Hyperf\\']
        ],
    ],
    [
        'class' => \App\Extended\Logger\SessionProcessor::class,
        'constructor' => [],
    ],
];

$formatter = ENV_LOCAL ? $lineFormatter : $jsonFormatter;

/*return [
    'default' => [
        'handler' => [
            'class' => Monolog\Handler\StreamHandler::class,
            'constructor' => [
                'stream' => BASE_PATH . '/runtime/logs/hyperf.log',
                'level' => Monolog\Logger::DEBUG,
            ],
        ],
        'formatter' => [
            'class' => Monolog\Formatter\LineFormatter::class,
            'constructor' => [
                'format' => null,
                'dateFormat' => 'Y-m-d H:i:s',
                'allowInlineLineBreaks' => true,
            ],
        ],
    ],
];*/

return [
    'default' => [
        'handler' => $defaultRotatingFileHandler,
        'formatter' => $formatter,
        'processors' => $processors,
    ],
    'app' => [
        'handler' => $defaultRotatingFileHandler,
        'formatter' => $formatter,
        'processors' => $processors,
    ],
    'sql' => [
        'handler' => $sqlRotatingFileHandler,
        'formatter' => $formatter,
        'processors' => $processors,
    ],
    'admin' => [
        'handler' => $adminRotatingFileHandler,
        'formatter' => $formatter,
        'processors' => [],
    ],
    'system' => [
        'handlers' => [
            $systemStdoutStreamHandler,
            $systemRotatingFileHandler
        ],
        'formatter' => $systemLineFormatter,
        'processors' => [],
    ],
    'queue' => [
        'handler' => $queueRotatingFileHandler,
        'formatter' => $formatter,
        'processors' => [],
    ],
];
